## 5/07/2018
## Analysis of the dental data from The Signal Tandmobiel Study
## This is R code fits the AFT model with Gaussian iid frailties in the paper
rm(list=ls())
library(spBayesSurv)
library(survival)
library(coda)
library(bayesSurv)
############## Read table ##############
data(tandmob2); 
# reshape data
d = reshape(tandmob2, 
            varying = list(c("EBEG.14", "EBEG.24", "EBEG.34", "EBEG.44"), 
                           c("EEND.14", "EEND.24", "EEND.34", "EEND.44"),
                           c("T54.DMF", "T64.DMF", "T74.DMF", "T84.DMF")),
            v.names = c("lower", "upper", "dmf"), timevar = "tooth",
            times = c(14, 24, 34, 44), direction = "long");
d$gender = d$GENDERNum;
d$idnr = d$IDNR;
d = d[,c("idnr", "tooth", "lower", "upper", "gender", "dmf")];
d = d[order(d$idnr),];
d$mandible = ((d$tooth==34)|(d$tooth==44))+0;
#head(d)

##-------------AFT-------------------##
# MCMC parameters
nburn=10000; nsave=2000; nskip=19; niter = nburn+nsave
mcmc=list(nburn=nburn, nsave=nsave, nskip=nskip, ndisplay=1000);
prior = list(maxL=15, a0=1, b0=1);
state <- list(cpar=1);
ptm<-proc.time()
res1 = survregbayes(formula = Surv(lower, upper, type="interval2")~gender+dmf+mandible+
                      dmf:mandible+dmf:gender+frailtyprior("iid",idnr), data=d, dist="loglogistic",
                     survmodel="AFT", selection=F, prior=prior, mcmc=mcmc, state=state);
sfit=summary(res1); sfit
systime1=proc.time()-ptm; systime1;
save.image("ResultAFT.RData")

############# traceplots ###############
par(mfrow = c(3,2))
traceplot(mcmc(res1$beta[1,]), main="");
traceplot(mcmc(res1$beta[2,]), main="");
traceplot(mcmc(res1$beta[3,]), main="");
traceplot(mcmc(res1$beta[4,]), main="");
traceplot(mcmc(res1$beta[5,]), main="")


